@@ -13,5 +13,5 @@ router.register("registries", views.RegistryViewSet)
 router.register("tokens", views.TokenViewSet)
 
 urlpatterns = router.urls + [
-    path('create_token/fungible/', views.create_fungible_token),
+    path('create_token/fungible/', views.create_token)
 ]
